stevedore – Manage Dynamic Plugins for Python Applications — stevedore 0.7 documentation

### Navigation

- index
- next |
- stevedore 0.7 documentation »

# stevedore – Manage Dynamic Plugins for Python Applications

Python makes loading code dynamically easy, allowing you to configure and extend your application by discovering and loading extensions (“plugins”) at runtime. Many applications implement their own library for doing this, using `__import__` or `importlib`. stevedore avoids creating yet another extension mechanism by building on top of setuptools entry points. The code for managing entry points tends to be repetitive, though, so stevedore provides manager classes for implementing common patterns for using dynamically loaded extensions.

Contents:

- Patterns for Loading
  - Drivers – Single Name, Single Entry Point
  - Hooks – Single Name, Many Entry Points
  - Extensions – Many Names, Many Entry Points
- Patterns for Enabling
  - Enabled Through Installation
  - Enabled Explicitly
  - Self-Enabled
- Extension Manager Classes
  - DriverManager
  - HookManager
  - NamedExtensionManager
  - EnabledExtensionManager
  - DispatchExtensionManager
  - NameDispatchExtensionManager
  - ExtensionManager
  - Extension
  - TestExtensionManager
- Installation
  - Python Versions
  - Basic Installation
  - Download
  - Source Code
  - Reporting Bugs
- History

## Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- stevedore 0.7 documentation »